pub fn whitespace(spaces: usize) -> Cow<'static, str>Expand description
Return a string of whitespace of the given length.
You can use this for indenting text with whitespace via Formatter::indented and
FormattedOutput::indented.
pub fn whitespace(spaces: usize) -> Cow<'static, str>Return a string of whitespace of the given length.
You can use this for indenting text with whitespace via Formatter::indented and
FormattedOutput::indented.